@@ -6,5 +6,6 @@ from . import cws
 from . import nli
 from . import pos
 from . import tc
+from . import re
 
-__all__ = ["absa","chunk","cws","ner","nli","pos","semp","summ","tc"]
\ No newline at end of file
+__all__ = ["absa","chunk","cws","ner","nli","pos","semp","summ","tc","re"]
\ No newline at end of file
