@@ -9,7 +9,6 @@ import scipy.stats as statss
 import json
 import random
 import numpy
-import numpy as np
 import codecs
 
 from seqeval.metrics import precision_score, recall_score, f1_score
@@ -1111,6 +1110,29 @@ def file_to_list_tc(path_file):
 	return sent_list, true_label_list, pred_label_list
 
 
+def file_to_list_re(file_path):
+	sample_list = []
+	fin = open(file_path,"r")
+	true_list = []
+	pred_list = []
+	sent_list = []
+	entity_list = []
+	for idx, line in enumerate(fin):
+		if idx == 0:
+			continue
+		info_list = line.rstrip("\n").split("\t")
+		sample_list.append([info for info in info_list])
+		true_list.append(info_list[3])
+		pred_list.append(info_list[4])
+		sent_list.append(info_list[0])
+		entity_list.append(info_list[1])
+
+	return sample_list, sent_list, entity_list, true_list, pred_list
+
+
+
+
+
 
 def file_to_list_nli(path_file):
 	sent1_list = []
@@ -1377,7 +1399,12 @@ def getErrorCase_tc(sent_list, true_label_list, pred_label_list):
     return errorCase_list
 
 
-
+def getErrorCase_re(sent_list, entity_list, true_label_list, pred_label_list):
+    errorCase_list = []
+    for sent, entities, true_label, pred_label in zip(sent_list, entity_list, true_label_list, pred_label_list):
+        if true_label != pred_label:
+            errorCase_list.append(true_label + "|||"  + pred_label +"|||" + entities + "|||" + format4json_tc(sent))
+    return errorCase_list
 
 
 
@@ -1426,6 +1453,50 @@ def getBucketAcc_with_errorCase(dict_bucket2span, dict_bucket2span_pred, dict_si
 
 	return sortDict(dict_bucket2f1)
 
+def getBucketAcc_with_errorCase_re(dict_bucket2span, dict_bucket2span_pred, dict_sid2sent, is_print_ci, is_print_case):
+
+
+	# The structure of span_true or span_pred
+	# 2345|||Positive
+	# 2345 represents sentence id
+	# Positive represents the "label" of this instance
+
+	dict_bucket2f1 = {}
+
+
+	for bucket_interval, spans_true in dict_bucket2span.items():
+		spans_pred = []
+		if bucket_interval not in dict_bucket2span_pred.keys():
+			raise ValueError("Predict Label Bucketing Errors")
+		else:
+			spans_pred = dict_bucket2span_pred[bucket_interval]
+
+
+
+		# loop over samples from a given bucket
+		error_case_bucket_list = []
+		if is_print_case:
+			for info_true, info_pred in zip(spans_true, spans_pred):
+				sid_true, label_true = info_true.split("|||")
+				sid_pred, label_pred = info_pred.split("|||")
+				if sid_true != sid_pred:
+					continue
+
+				sent_entities = dict_sid2sent[sid_true]
+				if label_true != label_pred:
+					error_case_info  =  label_true + "|||" + label_pred + "|||" + sent_entities
+					error_case_bucket_list.append(error_case_info)
+
+
+		accuracy_each_bucket = accuracy(spans_pred, spans_true)
+		confidence_low, confidence_up = 0,0
+		if is_print_ci:
+			confidence_low, confidence_up = compute_confidence_interval_acc(spans_pred, spans_true)
+		dict_bucket2f1[bucket_interval] = [accuracy_each_bucket, len(spans_true), confidence_low, confidence_up, error_case_bucket_list]
+
+
+
+	return sortDict(dict_bucket2f1)
 
 
 def getErrorCase_nli(sent1_list, sent2_list, true_label_list, pred_label_list):
